@@ -25,74 +25,64 @@ class UpgradeDBClusterVersionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'UpgradeDBClusterVersion','polardb')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_UpgradeType(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_UpgradeType(self): # String
 		return self.get_query_params().get('UpgradeType')
 
-	def set_UpgradeType(self,UpgradeType):
-		self.add_query_param('UpgradeType',UpgradeType)
-
-	def get_PlannedEndTime(self):
+	def set_UpgradeType(self, UpgradeType):  # String
+		self.add_query_param('UpgradeType', UpgradeType)
+	def get_PlannedEndTime(self): # String
 		return self.get_query_params().get('PlannedEndTime')
 
-	def set_PlannedEndTime(self,PlannedEndTime):
-		self.add_query_param('PlannedEndTime',PlannedEndTime)
-
-	def get_ResourceOwnerAccount(self):
+	def set_PlannedEndTime(self, PlannedEndTime):  # String
+		self.add_query_param('PlannedEndTime', PlannedEndTime)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_DBClusterId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_DBClusterId(self): # String
 		return self.get_query_params().get('DBClusterId')
 
-	def set_DBClusterId(self,DBClusterId):
-		self.add_query_param('DBClusterId',DBClusterId)
-
-	def get_UpgradeLabel(self):
+	def set_DBClusterId(self, DBClusterId):  # String
+		self.add_query_param('DBClusterId', DBClusterId)
+	def get_UpgradeLabel(self): # String
 		return self.get_query_params().get('UpgradeLabel')
 
-	def set_UpgradeLabel(self,UpgradeLabel):
-		self.add_query_param('UpgradeLabel',UpgradeLabel)
-
-	def get_OwnerAccount(self):
+	def set_UpgradeLabel(self, UpgradeLabel):  # String
+		self.add_query_param('UpgradeLabel', UpgradeLabel)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PlannedStartTime(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PlannedStartTime(self): # String
 		return self.get_query_params().get('PlannedStartTime')
 
-	def set_PlannedStartTime(self,PlannedStartTime):
-		self.add_query_param('PlannedStartTime',PlannedStartTime)
-
-	def get_UpgradePolicy(self):
+	def set_PlannedStartTime(self, PlannedStartTime):  # String
+		self.add_query_param('PlannedStartTime', PlannedStartTime)
+	def get_UpgradePolicy(self): # String
 		return self.get_query_params().get('UpgradePolicy')
 
-	def set_UpgradePolicy(self,UpgradePolicy):
-		self.add_query_param('UpgradePolicy',UpgradePolicy)
-
-	def get_FromTimeService(self):
+	def set_UpgradePolicy(self, UpgradePolicy):  # String
+		self.add_query_param('UpgradePolicy', UpgradePolicy)
+	def get_FromTimeService(self): # Boolean
 		return self.get_query_params().get('FromTimeService')
 
-	def set_FromTimeService(self,FromTimeService):
-		self.add_query_param('FromTimeService',FromTimeService)
\ No newline at end of file
+	def set_FromTimeService(self, FromTimeService):  # Boolean
+		self.add_query_param('FromTimeService', FromTimeService)
